@@ -1,31 +1,40 @@
 "add.lmomco.axis" <-
 function(side=1, twoside=FALSE,
          side.type=c("NPP", "RI", "SNV"), otherside.type=c("NA", "RI", "SNV", "NPP"),
-         alt.lab=NA, alt.other.lab=NA, npp.as.aep=FALSE,
+         alt.lab=NA, alt.other.lab=NA, npp.as.aep=FALSE, case=c("upper", "lower"),
          NPP.control=NULL, RI.control=NULL, SNV.control=NULL, ...) {
-
+   case <- match.arg(case)
    other.side <- switch(as.character(side), "1"=3, "2"=4, "3"=1, "4"=1)
 
    side.type      <- match.arg(side.type)
    otherside.type <- match.arg(otherside.type)
    if(otherside.type == "NA") otherside.type <- NA
    if(twoside & ! is.na(otherside.type)) twoside <- FALSE
-
+   lims <- par()$usr
+   ifelse(side == 1 | side == 3, lims <- lims[3:4], lims <- lims[1:2])
    "my.nonexceeds" <- function(minors=FALSE) {
       if(minors) {
-         F <- c(0.55, 0.65, 0.75, 0.825, 0.850, 0.875,
+         FF <- c(0.55, 0.65, 0.75, 0.825, 0.850, 0.875,
                 0.91, 0.92, 0.93, 0.94, 0.96, 0.97,
-                0.9925, 0.996, 0.997)
-         return(c(sort(1-F), F))
+                0.9925, 0.996, 0.997, 0.9996, 0.9997, 0.99996, 0.99997)
+         FF <- c(sort(1-FF), FF)
+         FF <- FF[FF > lims[1]]; FF <- FF[FF < lims[2]]
+         return(FF)
       } else {
-         F <- c(0.6, 0.7, 0.8, 0.9, 0.95, 0.98, 0.99, 0.995, 0.998, 0.999)
-         return(c(sort(1-F), 0.5, F))
+         FF <- c(0.6, 0.7, 0.8, 0.9, 0.95, 0.98, 0.99, 0.995, 0.998, 0.999,
+                 0.9995, 0.9998, 0.9999, 0.99995, 0.99998, 0.99999)
+         FF <- c(sort(1-FF), 0.5, FF)
+         FF <- FF[FF > lims[1]]; FF <- FF[FF < lims[2]]
+         return(FF)
       }
    }
 
    if(is.null(NPP.control)) {
-      the.label       <- ifelse(is.na(alt.lab),       "NONEXCEEDANCE PROBABILITY", alt.lab)
-      the.other.label <- ifelse(is.na(alt.other.lab), "EXCEEDANCE PROBABILITY",    alt.other.lab)
+      txt.npp <- ifelse(case == "upper", "NONEXCEEDANCE PROBABILITY", "Nonexceedance probability")
+      txt.epp <- ifelse(case == "upper", "EXCEEDANCE PROBABILITY",    "Exceedance probability")
+
+      the.label       <- ifelse(is.na(alt.lab),       txt.npp, alt.lab)
+      the.other.label <- ifelse(is.na(alt.other.lab), txt.epp, alt.other.lab)
       NPP.control <- list(label=the.label,
                           other.label=the.other.label,
                           probs=my.nonexceeds(minors=TRUE),
@@ -33,12 +42,14 @@ function(side=1, twoside=FALSE,
                           digits=3, line=3, as.exceed=FALSE)
    }
    if(is.null(RI.control)) {
-      the.label <- ifelse(is.na(alt.lab), "RECURRENCE INTERVAL, YEARS", alt.lab)
+      txt.ri <- ifelse(case == "upper", "RECURRENCE INTERVAL, IN YEARS", "Recurrence interval, in years")
+      the.label <- ifelse(is.na(alt.lab), txt.ri, alt.lab)
       RI.control <- list(label=the.label,
                          Tyear=c(2, 5, 10, 25, 50, 100, 200, 500), line=2)
    }
    if(is.null(SNV.control)) {
-      the.label <- ifelse(is.na(alt.lab), "STANDARD NORMAL VARIATE", alt.lab)
+      txt.snv <- ifelse(case == "upper", "STANDARD NORMAL VARIATE", "Standard normal variate")
+      the.label <- ifelse(is.na(alt.lab), txt.snv, alt.lab)
       SNV.control <- list(label=the.label,
                           begin=-5, end=5, by=0.5, line=2)
    }
